<?php
/**
 * Plugin Name: WP Category Merger
 * Plugin URI: https://example.com/wp-category-merger
 * Description: WordPress kategorilerini birleştirmenizi sağlayan güçlü bir eklenti. Allows you to merge WordPress categories easily.
 * Version: 1.0.0
 * Author: Manus AI
 * Text Domain: wp-category-merger
 * Domain Path: /languages
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

// Eklenti sabitleri
define('WP_CATEGORY_MERGER_VERSION', '1.0.0');
define('WP_CATEGORY_MERGER_PLUGIN_URL', plugin_dir_url(__FILE__));
define('WP_CATEGORY_MERGER_PLUGIN_PATH', plugin_dir_path(__FILE__));

class WP_Category_Merger {
    
    public function __construct() {
        add_action('init', array($this, 'init'));
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
        add_action('wp_ajax_merge_categories', array($this, 'ajax_merge_categories'));
        
        // Eklenti etkinleştirildiğinde
        register_activation_hook(__FILE__, array($this, 'activate'));
        
        // Eklenti devre dışı bırakıldığında
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));
    }
    
    public function init() {
        // Çeviri dosyalarını yükle
        load_plugin_textdomain('wp-category-merger', false, dirname(plugin_basename(__FILE__)) . '/languages');
    }
    
    public function add_admin_menu() {
        add_management_page(
            __('Category Merger', 'wp-category-merger'),
            __('Category Merger', 'wp-category-merger'),
            'manage_categories',
            'wp-category-merger',
            array($this, 'admin_page')
        );
    }
    
    public function enqueue_admin_scripts($hook) {
        if ($hook !== 'tools_page_wp-category-merger') {
            return;
        }
        
        wp_enqueue_script('jquery');
        wp_enqueue_script(
            'wp-category-merger-admin',
            WP_CATEGORY_MERGER_PLUGIN_URL . 'assets/admin.js',
            array('jquery'),
            WP_CATEGORY_MERGER_VERSION,
            true
        );
        
        wp_localize_script('wp-category-merger-admin', 'wpCategoryMerger', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('wp_category_merger_nonce'),
            'messages' => array(
                'select_source' => __('Please select a source category to keep.', 'wp-category-merger'),
                'select_target' => __('Please select a target category to merge.', 'wp-category-merger'),
                'same_category' => __('Source and target categories cannot be the same.', 'wp-category-merger'),
                'confirm_merge' => __('Are you sure you want to merge these categories? This action cannot be undone.', 'wp-category-merger'),
                'merging' => __('Merging categories...', 'wp-category-merger'),
                'success' => __('Categories merged successfully!', 'wp-category-merger'),
                'error' => __('An error occurred while merging categories.', 'wp-category-merger')
            )
        ));
        
        wp_enqueue_style(
            'wp-category-merger-admin',
            WP_CATEGORY_MERGER_PLUGIN_URL . 'assets/admin.css',
            array(),
            WP_CATEGORY_MERGER_VERSION
        );
    }
    
    public function admin_page() {
        // Kategorileri al
        $categories = get_categories(array(
            'hide_empty' => false,
            'orderby' => 'name',
            'order' => 'ASC'
        ));
        
        ?>
                <div class="wrap wp-category-merger">
            <h1><?php _e('Category Merger', 'wp-category-merger'); ?></h1>
            <p><?php _e('This tool allows you to merge two categories. All posts from the target category will be moved to the source category, and the target category will be deleted.', 'wp-category-merger'); ?></p>
            
            <div class="card">
                <h2><?php _e('Merge Categories', 'wp-category-merger'); ?></h2>
                
                <form id="category-merger-form">
                    <table class="form-table">
                        <tr>
                            <th scope="row">
                                <label for="source-category"><?php _e('Source Category (Keep)', 'wp-category-merger'); ?></label>
                            </th>
                            <td>
                                <select id="source-category" name="source_category" class="regular-text">
                                    <option value=""><?php _e('Select a category to keep...', 'wp-category-merger'); ?></option>
                                    <?php foreach ($categories as $category): ?>
                                        <option value="<?php echo esc_attr($category->term_id); ?>">
                                            <?php echo esc_html($category->name); ?> 
                                            (<?php printf(_n('%d post', '%d posts', $category->count, 'wp-category-merger'), $category->count); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                <p class="description"><?php _e('This category will be kept and all posts will be moved here.', 'wp-category-merger'); ?></p>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row">
                                <label for="target-category"><?php _e('Target Category (Merge)', 'wp-category-merger'); ?></label>
                            </th>
                            <td>
                                <select id="target-category" name="target_category" class="regular-text">
                                    <option value=""><?php _e('Select a category to merge...', 'wp-category-merger'); ?></option>
                                    <?php foreach ($categories as $category): ?>
                                        <option value="<?php echo esc_attr($category->term_id); ?>">
                                            <?php echo esc_html($category->name); ?> 
                                            (<?php printf(_n('%d post', '%d posts', $category->count, 'wp-category-merger'), $category->count); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                <p class="description"><?php _e('This category will be deleted and its posts moved to the source category.', 'wp-category-merger'); ?></p>
                            </td>
                        </tr>
                    </table>
                    
                    <p class="submit">
                        <button type="submit" class="button button-primary" id="merge-button">
                            <?php _e('Start Merge', 'wp-category-merger'); ?>
                        </button>
                    </p>
                </form>
                
                <div id="merge-result" style="display: none;"></div>
            </div>
        </div>
        <?php
    }
    
    public function ajax_merge_categories() {
        // Nonce kontrolü
        if (!wp_verify_nonce($_POST['nonce'], 'wp_category_merger_nonce')) {
            wp_die(__('Security check failed.', 'wp-category-merger'));
        }
        
        // Yetki kontrolü
        if (!current_user_can('manage_categories')) {
            wp_send_json_error(__('You do not have permission to manage categories.', 'wp-category-merger'));
        }
        
        $source_category_id = intval($_POST['source_category']);
        $target_category_id = intval($_POST['target_category']);
        
        // Kategori ID'lerini kontrol et
        if (empty($source_category_id) || empty($target_category_id)) {
            wp_send_json_error(__('Please select both source and target categories.', 'wp-category-merger'));
        }
        
        if ($source_category_id === $target_category_id) {
            wp_send_json_error(__('Source and target categories cannot be the same.', 'wp-category-merger'));
        }
        
        // Kategorilerin var olduğunu kontrol et
        $source_category = get_category($source_category_id);
        $target_category = get_category($target_category_id);
        
        if (is_wp_error($source_category) || is_wp_error($target_category)) {
            wp_send_json_error(__('One or both categories do not exist.', 'wp-category-merger'));
        }
        
        // Kategori birleştirme işlemini gerçekleştir
        $result = $this->merge_categories($source_category_id, $target_category_id);
        
        if ($result['success']) {
            wp_send_json_success($result['message']);
        } else {
            wp_send_json_error($result['message']);
        }
    }
    
    private function merge_categories($source_category_id, $target_category_id) {
        global $wpdb;
        
        try {
            // Hedef kategorideki tüm yazıları al
            $posts_in_target = get_posts(array(
                'category' => $target_category_id,
                'numberposts' => -1,
                'post_status' => 'any',
                'fields' => 'ids'
            ));
            
            $moved_posts = 0;
            
            // Her yazı için kategori değişikliği yap
            foreach ($posts_in_target as $post_id) {
                // Yazının mevcut kategorilerini al
                $current_categories = wp_get_post_categories($post_id);
                
                // Hedef kategoriyi kaldır ve kaynak kategoriyi ekle
                $new_categories = array_diff($current_categories, array($target_category_id));
                
                // Kaynak kategori zaten yoksa ekle
                if (!in_array($source_category_id, $new_categories)) {
                    $new_categories[] = $source_category_id;
                }
                
                // Kategorileri güncelle
                $result = wp_set_post_categories($post_id, $new_categories);
                
                if (!is_wp_error($result)) {
                    $moved_posts++;
                }
            }
            
            // Hedef kategoriyi sil
            $delete_result = wp_delete_category($target_category_id);
            
            if (is_wp_error($delete_result)) {
                return array(
                    'success' => false,
                    'message' => sprintf(
                        __('Posts were moved but failed to delete the target category: %s', 'wp-category-merger'),
                        $delete_result->get_error_message()
                    )
                );
            }
            
            return array(
                'success' => true,
                'message' => sprintf(
                    __('Successfully merged categories! %d posts were moved and the target category was deleted.', 'wp-category-merger'),
                    $moved_posts
                )
            );
            
        } catch (Exception $e) {
            return array(
                'success' => false,
                'message' => sprintf(
                    __('An error occurred during the merge process: %s', 'wp-category-merger'),
                    $e->getMessage()
                )
            );
        }
    }
    
    public function activate() {
        // Eklenti etkinleştirildiğinde yapılacak işlemler
        if (!current_user_can('manage_categories')) {
            wp_die(__('You do not have sufficient permissions to activate this plugin.', 'wp-category-merger'));
        }
    }
    
    public function deactivate() {
        // Eklenti devre dışı bırakıldığında yapılacak işlemler
    }
}

// Eklentiyi başlat
new WP_Category_Merger();

